diff pkg/imports/sec.go @ 3307:b90b17d0b5a9 sections-backend

added sections_geoserver view, renamed stretch column to section in schema
author Markus Kottlaender <markus@intevation.de>
date Fri, 17 May 2019 11:28:20 +0200
parents bfde4f8dd323
children f10d606b2931
line wrap: on
line diff
--- a/pkg/imports/sec.go	Fri May 17 10:03:07 2019 +0200
+++ b/pkg/imports/sec.go	Fri May 17 11:28:20 2019 +0200
@@ -101,7 +101,7 @@
   SELECT ISRSrange_axis((SELECT r FROM r), $16::double precision) AS axs)
 INSERT INTO waterway.sections (
   name,
-  stretch,
+  section,
   area,
   objnam,
   nobjnam,
@@ -121,7 +121,7 @@
 RETURNING id`
 )
 
 // StageDone moves the imported stretch out of the staging area.
 func (secJobCreator) StageDone(
 	ctx context.Context,
 	tx *sql.Tx,
@@ -134,10 +134,10 @@
 	return err
 }
 
 // CleanUp of a stretch import is a NOP.
 func (*Section) CleanUp() error { return nil }
 
 // Do executes the actual stretch import.
 func (sec *Section) Do(
 	ctx context.Context,
 	importID int64,
@@ -121,7 +121,7 @@
 )
 
-// StageDone moves the imported stretch out of the staging area.
+// StageDone moves the imported section out of the staging area.
 func (secJobCreator) StageDone(
 	ctx context.Context,
@@ -134,10 +134,10 @@
 }
 
-// CleanUp of a stretch import is a NOP.
+// CleanUp of a section import is a NOP.
 func (*Section) CleanUp() error { return nil }
 
@@ -134,10 +134,10 @@
 func (*Section) CleanUp() error { return nil }
 
-// Do executes the actual stretch import.
+// Do executes the actual section import.
 func (sec *Section) Do(
 	ctx context.Context,